@@ -18,7 +18,7 @@ fieldhash my %maxlevel => 'maxlevel';
 fieldhash my %minlevel => 'minlevel';
 fieldhash my %url      => 'url';
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 # -----------------------------------------------
 
@@ -385,18 +385,18 @@ to non-HTML resources (CSS, JS) point to real files.
 
 =head2 How does the -maxlevel parameter affect the output?
 
-In these examples, $DR stands for the /dev/shm/html/ directory.
+In these examples, $DR stands for the /dev/shm/html/ directory, the doc root of my dev box's web server.
 
 Output from a real run, where my dev web site is the same as my real web site (so -d $DR works):
 
 	shell> validate.head.links.pl -d $DR -url http://savage.net.au/Novels-etc.html -max debug
 
 	URL: http://savage.net.au/Novels-etc.html
-	 Import: /dev/shm/html/assets/js/DataTables-1.9.2/media/css/demo_page.css
-	 Import: /dev/shm/html/assets/js/DataTables-1.9.2/media/css/demo_table.css
+	 Import: /dev/shm/html/assets/js/DataTables-1.9.4/media/css/demo_page.css
+	 Import: /dev/shm/html/assets/js/DataTables-1.9.4/media/css/demo_table.css
 	   Link: /dev/shm/html/assets/css/local/default.css
-	 Script: /dev/shm/html/assets/js/DataTables-1.9.2/media/js/jquery.js
-	 Script: /dev/shm/html/assets/js/DataTables-1.9.2/media/js/jquery.dataTables.min.js
+	 Script: /dev/shm/html/assets/js/DataTables-1.9.4/media/js/jquery.js
+	 Script: /dev/shm/html/assets/js/DataTables-1.9.4/media/js/jquery.dataTables.min.js
 	Imports: 2. Errors: 0
 	  Links: 1. Errors: 0
 	Scripts: 2. Errors: 0
@@ -411,6 +411,9 @@ Output from a real run, where my dev web site is the same as my real web site (s
 
 	(No output)
 
+	shell> echo $?
+	0
+
 =head1 Support
 
 Email the author, or log a bug on RT:
